mirador package
===============

Subpackages
-----------

.. toctree::

    mirador.errors
    mirador.ext
    mirador.test

Submodules
----------

mirador.client module
---------------------

.. automodule:: mirador.client
    :members:
    :undoc-members:
    :show-inheritance:

mirador.result module
---------------------

.. automodule:: mirador.result
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mirador
    :members:
    :undoc-members:
    :show-inheritance:
